==> legalios-0.0.7.crate: legalios-0.0.7/src/providers/period_2018/provider_salary_2018.rs <==
﻿use crate::props::props::IProps;
use crate::props::props_salary::PropsSalary;
use crate::providers::history_const_salary::HistoryConstSalary;
use crate::providers::period_2018::history_const_salary_2018::HistoryConstSalary2018;
use crate::providers::props_provider::IPropsProvider;
use crate::service::period::IPeriod;
use crate::service::version_id::VersionId;

pub(crate) struct ProviderSalary2018 {
    version: VersionId
}

#[allow(dead_code)]
impl ProviderSalary2018 {
    pub(crate) fn new() -> ProviderSalary2018 {
        ProviderSalary2018 {
            version: VersionId::get(HistoryConstSalary2018::VERSION_CODE)
        }
    }
    fn working_shift_week(&self, _period: &dyn IPeriod) -> i32 {
        HistoryConstSalary2018::WORKING_SHIFT_WEEK
    }

    fn working_shift_time(&self, _period: &dyn IPeriod) -> i32 {
        HistoryConstSalary2018::WORKING_SHIFT_TIME
    }
    fn min_monthly_wage(&self, _period: &dyn IPeriod) -> i32 {
        HistoryConstSalary2018::MIN_MONTHLY_WAGE
    }
    fn min_hourly_wage(&self, _period: &dyn IPeriod) -> i32 {
        HistoryConstSalary2018::MIN_HOURLY_WAGE
    }
}

impl IProps for ProviderSalary2018 {
    fn get_version(&self) -> VersionId {
        self.version
    }
}

impl IPropsProvider<PropsSalary> for ProviderSalary2018 {
    fn get_version(&self) -> VersionId {
        self.version
    }
    fn get_props(&self, _period: &dyn IPeriod) -> PropsSalary {
        PropsSalary::new(self.version,
                         self.working_shift_week(_period),
                         self.working_shift_time(_period),
                         self.min_monthly_wage(_period),
                         self.min_hourly_wage(_period))
    }
}

==> legalios-0.22.2.crate: legalios-0.22.2/src/providers/period_2018/provider_salary_2018.rs <==
﻿use crate::factories::provider_factory::BoxSalaryProps;
use crate::props::props::IProps;
use crate::props::props_salary::PropsSalary;
use crate::providers::history_const_salary::HistoryConstSalary;
use crate::providers::period_2018::history_const_salary_2018::HistoryConstSalary2018;
use crate::providers::props_provider::{IPropsSalaryProvider};
use crate::service::period::IPeriod;
use crate::service::version_id::VersionId;

pub(crate) struct ProviderSalary2018 {
    version: VersionId
}

#[allow(dead_code)]
impl ProviderSalary2018 {
    pub(crate) fn new() -> ProviderSalary2018 {
        ProviderSalary2018 {
            version: VersionId::get(HistoryConstSalary2018::VERSION_CODE)
        }
    }
    fn working_shift_week(&self, _period: &dyn IPeriod) -> i32 {
        HistoryConstSalary2018::WORKING_SHIFT_WEEK
    }

    fn working_shift_time(&self, _period: &dyn IPeriod) -> i32 {
        HistoryConstSalary2018::WORKING_SHIFT_TIME
    }
    fn min_monthly_wage(&self, _period: &dyn IPeriod) -> i32 {
        HistoryConstSalary2018::MIN_MONTHLY_WAGE
    }
    fn min_hourly_wage(&self, _period: &dyn IPeriod) -> i32 {
        HistoryConstSalary2018::MIN_HOURLY_WAGE
    }
}

impl IProps for ProviderSalary2018 {
    fn get_version(&self) -> VersionId {
        self.version
    }
}

impl IPropsSalaryProvider for ProviderSalary2018 {
    fn get_version(&self) -> VersionId {
        self.version
    }
    fn get_props(&self, _period: &dyn IPeriod) -> BoxSalaryProps {
        Box::new(PropsSalary::new(self.version,
                         self.working_shift_week(_period),
                         self.working_shift_time(_period),
                         self.min_monthly_wage(_period),
                         self.min_hourly_wage(_period)))
    }
}
